@@ -101,8 +101,16 @@
 //! # }
 //! ```
 
-#[cfg(test)]
-mod tests;
+#[cfg(all(
+    feature = "serialize",
+    not(any(
+        feature = "serialize_bincode",
+        feature = "serialize_rmp",
+        feature = "serialize_postcard",
+        feature = "serialize_json"
+    ))
+))]
+compile_error!("Feature 'serialize' cannot be used by its own. Choose one of 'serialize_rmp', 'serialize_bincode', 'serialize_postcard', 'serialize_json instead.");
 
 pub mod error;
 mod events;
